@@ -1,25 +1,22 @@
-# -*- coding: utf-8 -*-
 # emacs: -*- mode: python; py-indent-offset: 4; indent-tabs-mode: nil -*-
 # vi: set ft=python sts=4 ts=4 sw=4 et:
 """
-Surface preprocessing workflows
--------------------------------
+Surface preprocessing workflows.
 
-``smriprep`` uses FreeSurfer_ to reconstruct surfaces from T1w/T2w
+**sMRIPrep** uses FreeSurfer to reconstruct surfaces from T1w/T2w
 structural images.
 
-.. autofunction:: init_surface_recon_wf
-.. autofunction:: init_autorecon_resume_wf
-.. autofunction:: init_gifti_surface_wf
-
 """
 from nipype.pipeline import engine as pe
+from nipype.interfaces.base import Undefined
 from nipype.interfaces import (
     io as nio,
     utility as niu,
     freesurfer as fs,
 )
 
+from ..interfaces.freesurfer import ReconAll
+
 from niworkflows.engine.workflows import LiterateWorkflow as Workflow
 from niworkflows.interfaces.freesurfer import (
     FSDetectInputs,
@@ -29,13 +26,12 @@ from niworkflows.interfaces.freesurfer import (
     PatchedRobustRegister as RobustRegister,
     RefineBrainMask,
 )
-from niworkflows.interfaces.segmentation import ReconAllRPT
 from niworkflows.interfaces.surf import NormalizeSurf
 
 
 def init_surface_recon_wf(omp_nthreads, hires, name='surface_recon_wf'):
     r"""
-    This workflow reconstructs anatomical surfaces using FreeSurfer's ``recon-all``.
+    Reconstruct anatomical surfaces using FreeSurfer's ``recon-all``.
 
     Reconstruction is performed in three phases.
     The first phase initializes the subject with T1w and T2w (if available)
@@ -81,80 +77,75 @@ def init_surface_recon_wf(omp_nthreads, hires, name='surface_recon_wf'):
     This procedure is inspired on mindboggle's solution to the problem:
     https://github.com/nipy/mindboggle/blob/7f91faaa7664d820fe12ccc52ebaf21d679795e2/mindboggle/guts/segment.py#L1660
 
-
     The final phase resumes reconstruction, using the T2w image to assist
     in finding the pial surface, if available.
     See :py:func:`~smriprep.workflows.surfaces.init_autorecon_resume_wf` for details.
 
-
     Memory annotations for FreeSurfer are based off `their documentation
     <https://surfer.nmr.mgh.harvard.edu/fswiki/SystemRequirements>`_.
     They specify an allocation of 4GB per subject. Here we define 5GB
     to have a certain margin.
 
+    Workflow Graph
+        .. workflow::
+            :graph2use: orig
+            :simple_form: yes
 
+            from smriprep.workflows.surfaces import init_surface_recon_wf
+            wf = init_surface_recon_wf(omp_nthreads=1, hires=True)
 
-    .. workflow::
-        :graph2use: orig
-        :simple_form: yes
+    Parameters
+    ----------
+    omp_nthreads : int
+        Maximum number of threads an individual process may use
+    hires : bool
+        Enable sub-millimeter preprocessing in FreeSurfer
 
-        from smriprep.workflows.surfaces import init_surface_recon_wf
-        wf = init_surface_recon_wf(omp_nthreads=1, hires=True)
+    Inputs
+    ------
+    t1w
+        List of T1-weighted structural images
+    t2w
+        List of T2-weighted structural images (only first used)
+    flair
+        List of FLAIR images
+    skullstripped_t1
+        Skull-stripped T1-weighted image (or mask of image)
+    ants_segs
+        Brain tissue segmentation from ANTS ``antsBrainExtraction.sh``
+    corrected_t1
+        INU-corrected, merged T1-weighted image
+    subjects_dir
+        FreeSurfer SUBJECTS_DIR
+    subject_id
+        FreeSurfer subject ID
 
-    **Parameters**
+    Outputs
+    -------
+    subjects_dir
+        FreeSurfer SUBJECTS_DIR
+    subject_id
+        FreeSurfer subject ID
+    t1w2fsnative_xfm
+        LTA-style affine matrix translating from T1w to FreeSurfer-conformed subject space
+    fsnative2t1w_xfm
+        LTA-style affine matrix translating from FreeSurfer-conformed subject space to T1w
+    surfaces
+        GIFTI surfaces for gray/white matter boundary, pial surface,
+        midthickness (or graymid) surface, and inflated surfaces
+    out_brainmask
+        Refined brainmask, derived from FreeSurfer's ``aseg`` volume
+    out_aseg
+        FreeSurfer's aseg segmentation, in native T1w space
+    out_aparc
+        FreeSurfer's aparc+aseg segmentation, in native T1w space
 
-        omp_nthreads : int
-            Maximum number of threads an individual process may use
-        hires : bool
-            Enable sub-millimeter preprocessing in FreeSurfer
+    See also
+    --------
+    * :py:func:`~smriprep.workflows.surfaces.init_autorecon_resume_wf`
+    * :py:func:`~smriprep.workflows.surfaces.init_gifti_surface_wf`
 
-    **Inputs**
-
-        t1w
-            List of T1-weighted structural images
-        t2w
-            List of T2-weighted structural images (only first used)
-        flair
-            List of FLAIR images
-        skullstripped_t1
-            Skull-stripped T1-weighted image (or mask of image)
-        ants_segs
-            Brain tissue segmentation from ANTS ``antsBrainExtraction.sh``
-        corrected_t1
-            INU-corrected, merged T1-weighted image
-        subjects_dir
-            FreeSurfer SUBJECTS_DIR
-        subject_id
-            FreeSurfer subject ID
-
-    **Outputs**
-
-        subjects_dir
-            FreeSurfer SUBJECTS_DIR
-        subject_id
-            FreeSurfer subject ID
-        t1_2_fsnative_forward_transform
-            LTA-style affine matrix translating from T1w to FreeSurfer-conformed subject space
-        t1_2_fsnative_reverse_transform
-            LTA-style affine matrix translating from FreeSurfer-conformed subject space to T1w
-        surfaces
-            GIFTI surfaces for gray/white matter boundary, pial surface,
-            midthickness (or graymid) surface, and inflated surfaces
-        out_brainmask
-            Refined brainmask, derived from FreeSurfer's ``aseg`` volume
-        out_aseg
-            FreeSurfer's aseg segmentation, in native T1w space
-        out_aparc
-            FreeSurfer's aparc+aseg segmentation, in native T1w space
-        out_report
-            Reportlet visualizing quality of surface alignment
-
-    **Subworkflows**
-
-        * :py:func:`~smriprep.workflows.surfaces.init_autorecon_resume_wf`
-        * :py:func:`~smriprep.workflows.surfaces.init_gifti_surface_wf`
     """
-
     workflow = Workflow(name=name)
     workflow.__desc__ = """\
 Brain surfaces were reconstructed using `recon-all` [FreeSurfer {fs_ver},
@@ -170,9 +161,9 @@ gray-matter of Mindboggle [RRID:SCR_002438, @mindboggle].
                     'subjects_dir', 'subject_id']), name='inputnode')
     outputnode = pe.Node(
         niu.IdentityInterface(
-            fields=['subjects_dir', 'subject_id', 't1_2_fsnative_forward_transform',
-                    't1_2_fsnative_reverse_transform', 'surfaces', 'out_brainmask',
-                    'out_aseg', 'out_aparc', 'out_report']),
+            fields=['subjects_dir', 'subject_id', 't1w2fsnative_xfm',
+                    'fsnative2t1w_xfm', 'surfaces', 'out_brainmask',
+                    'out_aseg', 'out_aparc']),
         name='outputnode')
 
     recon_config = pe.Node(FSDetectInputs(hires_enabled=hires), name='recon_config')
@@ -180,17 +171,17 @@ gray-matter of Mindboggle [RRID:SCR_002438, @mindboggle].
     fov_check = pe.Node(niu.Function(function=_check_cw256), name='fov_check')
 
     autorecon1 = pe.Node(
-        fs.ReconAll(directive='autorecon1', openmp=omp_nthreads),
+        ReconAll(directive='autorecon1', openmp=omp_nthreads),
         name='autorecon1', n_procs=omp_nthreads, mem_gb=5)
     autorecon1.interface._can_resume = False
     autorecon1.interface._always_run = True
 
     skull_strip_extern = pe.Node(FSInjectBrainExtracted(), name='skull_strip_extern')
 
-    fsnative_2_t1_xfm = pe.Node(RobustRegister(auto_sens=True, est_int_scale=True),
-                                name='fsnative_2_t1_xfm')
-    t1_2_fsnative_xfm = pe.Node(LTAConvert(out_lta=True, invert=True),
-                                name='t1_2_fsnative_xfm')
+    fsnative2t1w_xfm = pe.Node(RobustRegister(auto_sens=True, est_int_scale=True),
+                               name='fsnative2t1w_xfm')
+    t1w2fsnative_xfm = pe.Node(LTAConvert(out_lta=True, invert=True),
+                               name='t1w2fsnative_xfm')
 
     autorecon_resume_wf = init_autorecon_resume_wf(omp_nthreads=omp_nthreads)
     gifti_surface_wf = init_gifti_surface_wf()
@@ -228,11 +219,11 @@ gray-matter of Mindboggle [RRID:SCR_002438, @mindboggle].
                                              ('use_flair', 'inputnode.use_FLAIR')]),
         # Construct transform from FreeSurfer conformed image to sMRIPrep
         # reoriented image
-        (inputnode, fsnative_2_t1_xfm, [('t1w', 'target_file')]),
-        (autorecon1, fsnative_2_t1_xfm, [('T1', 'source_file')]),
-        (fsnative_2_t1_xfm, gifti_surface_wf, [
-            ('out_reg_file', 'inputnode.t1_2_fsnative_reverse_transform')]),
-        (fsnative_2_t1_xfm, t1_2_fsnative_xfm, [('out_reg_file', 'in_lta')]),
+        (inputnode, fsnative2t1w_xfm, [('t1w', 'target_file')]),
+        (autorecon1, fsnative2t1w_xfm, [('T1', 'source_file')]),
+        (fsnative2t1w_xfm, gifti_surface_wf, [
+            ('out_reg_file', 'inputnode.fsnative2t1w_xfm')]),
+        (fsnative2t1w_xfm, t1w2fsnative_xfm, [('out_reg_file', 'in_lta')]),
         # Refine ANTs mask, deriving new mask from FS' aseg
         (inputnode, refine, [('corrected_t1', 'in_anat'),
                              ('ants_segs', 'in_ants')]),
@@ -248,11 +239,10 @@ gray-matter of Mindboggle [RRID:SCR_002438, @mindboggle].
 
         # Output
         (autorecon_resume_wf, outputnode, [('outputnode.subjects_dir', 'subjects_dir'),
-                                           ('outputnode.subject_id', 'subject_id'),
-                                           ('outputnode.out_report', 'out_report')]),
+                                           ('outputnode.subject_id', 'subject_id')]),
         (gifti_surface_wf, outputnode, [('outputnode.surfaces', 'surfaces')]),
-        (t1_2_fsnative_xfm, outputnode, [('out_lta', 't1_2_fsnative_forward_transform')]),
-        (fsnative_2_t1_xfm, outputnode, [('out_reg_file', 't1_2_fsnative_reverse_transform')]),
+        (t1w2fsnative_xfm, outputnode, [('out_lta', 't1w2fsnative_xfm')]),
+        (fsnative2t1w_xfm, outputnode, [('out_reg_file', 'fsnative2t1w_xfm')]),
         (refine, outputnode, [('out_file', 'out_brainmask')]),
         (aseg_to_native_wf, outputnode, [('outputnode.out_file', 'out_aseg')]),
         (aparc_to_native_wf, outputnode, [('outputnode.out_file', 'out_aparc')]),
@@ -263,61 +253,62 @@ gray-matter of Mindboggle [RRID:SCR_002438, @mindboggle].
 
 def init_autorecon_resume_wf(omp_nthreads, name='autorecon_resume_wf'):
     r"""
-    This workflow resumes recon-all execution, assuming the `-autorecon1` stage
-    has been completed.
+    Resume recon-all execution, assuming the `-autorecon1` stage has been completed.
 
-    In order to utilize resources efficiently, this is broken down into five
+    In order to utilize resources efficiently, this is broken down into seven
     sub-stages; after the first stage, the second and third stages may be run
-    simultaneously, and the fourth and fifth stages may be run simultaneously,
-    if resources permit::
+    simultaneously, and the fifth and sixth stages may be run simultaneously,
+    if resources permit; the fourth stage must be run prior to the fifth and
+    sixth, and the seventh must be run after::
 
         $ recon-all -sd <output dir>/freesurfer -subjid sub-<subject_label> \
             -autorecon2-volonly
         $ recon-all -sd <output dir>/freesurfer -subjid sub-<subject_label> \
-            -autorecon-hemi lh \
-            -noparcstats -nocortparc2 -noparcstats2 -nocortparc3 \
-            -noparcstats3 -nopctsurfcon -nohyporelabel -noaparc2aseg \
-            -noapas2aseg -nosegstats -nowmparc -nobalabels
+            -autorecon-hemi lh -T2pial \
+            -noparcstats -noparcstats2 -noparcstats3 -nohyporelabel -nobalabels
         $ recon-all -sd <output dir>/freesurfer -subjid sub-<subject_label> \
-            -autorecon-hemi rh \
-            -noparcstats -nocortparc2 -noparcstats2 -nocortparc3 \
-            -noparcstats3 -nopctsurfcon -nohyporelabel -noaparc2aseg \
-            -noapas2aseg -nosegstats -nowmparc -nobalabels
+            -autorecon-hemi rh -T2pial \
+            -noparcstats -noparcstats2 -noparcstats3 -nohyporelabel -nobalabels
         $ recon-all -sd <output dir>/freesurfer -subjid sub-<subject_label> \
-            -autorecon3 -hemi lh -T2pial
+            -cortribbon
         $ recon-all -sd <output dir>/freesurfer -subjid sub-<subject_label> \
-            -autorecon3 -hemi rh -T2pial
+            -autorecon-hemi lh -nohyporelabel
+        $ recon-all -sd <output dir>/freesurfer -subjid sub-<subject_label> \
+            -autorecon-hemi rh -nohyporelabel
+        $ recon-all -sd <output dir>/freesurfer -subjid sub-<subject_label> \
+            -autorecon3
 
-    The excluded steps in the second and third stages (``-no<option>``) are not
-    fully hemisphere independent, and are therefore postponed to the final two
-    stages.
+    The parcellation statistics steps are excluded from the second and third
+    stages, because they require calculation of the cortical ribbon volume
+    (the fourth stage).
+    Hypointensity relabeling is excluded from hemisphere-specific steps to avoid
+    race conditions, as it is a volumetric operation.
 
-    .. workflow::
-        :graph2use: orig
-        :simple_form: yes
+    Workflow Graph
+        .. workflow::
+            :graph2use: orig
+            :simple_form: yes
 
-        from smriprep.workflows.surfaces import init_autorecon_resume_wf
-        wf = init_autorecon_resume_wf(omp_nthreads=1)
+            from smriprep.workflows.surfaces import init_autorecon_resume_wf
+            wf = init_autorecon_resume_wf(omp_nthreads=1)
 
-    **Inputs**
+    Inputs
+    ------
+    subjects_dir
+        FreeSurfer SUBJECTS_DIR
+    subject_id
+        FreeSurfer subject ID
+    use_T2
+        Refine pial surface using T2w image
+    use_FLAIR
+        Refine pial surface using FLAIR image
 
-        subjects_dir
-            FreeSurfer SUBJECTS_DIR
-        subject_id
-            FreeSurfer subject ID
-        use_T2
-            Refine pial surface using T2w image
-        use_FLAIR
-            Refine pial surface using FLAIR image
-
-    **Outputs**
-
-        subjects_dir
-            FreeSurfer SUBJECTS_DIR
-        subject_id
-            FreeSurfer subject ID
-        out_report
-            Reportlet visualizing quality of surface alignment
+    Outputs
+    -------
+    subjects_dir
+        FreeSurfer SUBJECTS_DIR
+    subject_id
+        FreeSurfer subject ID
 
     """
     workflow = Workflow(name=name)
@@ -329,39 +320,54 @@ def init_autorecon_resume_wf(omp_nthreads, name='autorecon_resume_wf'):
 
     outputnode = pe.Node(
         niu.IdentityInterface(
-            fields=['subjects_dir', 'subject_id', 'out_report']),
+            fields=['subjects_dir', 'subject_id']),
         name='outputnode')
 
     autorecon2_vol = pe.Node(
-        fs.ReconAll(directive='autorecon2-volonly', openmp=omp_nthreads),
+        ReconAll(directive='autorecon2-volonly', openmp=omp_nthreads),
         n_procs=omp_nthreads, mem_gb=5, name='autorecon2_vol')
     autorecon2_vol.interface._always_run = True
 
     autorecon_surfs = pe.MapNode(
-        fs.ReconAll(
+        ReconAll(
             directive='autorecon-hemi',
-            flags=['-noparcstats', '-nocortparc2', '-noparcstats2',
-                   '-nocortparc3', '-noparcstats3', '-nopctsurfcon',
-                   '-nohyporelabel', '-noaparc2aseg', '-noapas2aseg',
-                   '-nosegstats', '-nowmparc', '-nobalabels'],
+            flags=['-noparcstats', '-noparcstats2', '-noparcstats3',
+                   '-nohyporelabel', '-nobalabels'],
             openmp=omp_nthreads),
         iterfield='hemi', n_procs=omp_nthreads, mem_gb=5,
         name='autorecon_surfs')
     autorecon_surfs.inputs.hemi = ['lh', 'rh']
     autorecon_surfs.interface._always_run = True
 
-    autorecon3 = pe.MapNode(
-        fs.ReconAll(directive='autorecon3', openmp=omp_nthreads),
-        iterfield='hemi', n_procs=omp_nthreads, mem_gb=5,
-        name='autorecon3')
-    autorecon3.inputs.hemi = ['lh', 'rh']
-    autorecon3.interface._always_run = True
+    # -cortribbon is a prerequisite for -parcstats, -parcstats2, -parcstats3
+    # Claiming two threads because pial refinement can be split by hemisphere
+    # if -T2pial or -FLAIRpial is enabled.
+    # Parallelizing by hemisphere saves ~30 minutes over simply enabling
+    # OpenMP on an 8 core machine.
+    cortribbon = pe.Node(ReconAll(directive=Undefined, steps=['cortribbon'],
+                                  parallel=True),
+                         n_procs=2, name='cortribbon')
+    cortribbon.interface._always_run = True
 
-    # Only generate the report once; should be nothing to do
-    recon_report = pe.Node(
-        ReconAllRPT(directive='autorecon3', generate_report=True),
-        name='recon_report', mem_gb=5)
-    recon_report.interface._always_run = True
+    # -parcstats* can be run per-hemisphere
+    # -hyporelabel is volumetric, even though it's part of -autorecon-hemi
+    parcstats = pe.MapNode(
+        ReconAll(
+            directive='autorecon-hemi',
+            flags=['-nohyporelabel'],
+            openmp=omp_nthreads),
+        iterfield='hemi', n_procs=omp_nthreads, mem_gb=5,
+        name='parcstats')
+    parcstats.inputs.hemi = ['lh', 'rh']
+    parcstats.interface._always_run = True
+
+    # Runs: -hyporelabel -aparc2aseg -apas2aseg -segstats -wmparc
+    # All volumetric, so don't
+    autorecon3 = pe.Node(
+        ReconAll(directive='autorecon3', openmp=omp_nthreads),
+        n_procs=omp_nthreads, mem_gb=5,
+        name='autorecon3')
+    autorecon3.interface._always_run = True
 
     def _dedup(in_list):
         vals = set(in_list)
@@ -371,19 +377,20 @@ def init_autorecon_resume_wf(omp_nthreads, name='autorecon_resume_wf'):
         return vals.pop()
 
     workflow.connect([
-        (inputnode, autorecon3, [('use_T2', 'use_T2'),
+        (inputnode, cortribbon, [('use_T2', 'use_T2'),
                                  ('use_FLAIR', 'use_FLAIR')]),
         (inputnode, autorecon2_vol, [('subjects_dir', 'subjects_dir'),
                                      ('subject_id', 'subject_id')]),
         (autorecon2_vol, autorecon_surfs, [('subjects_dir', 'subjects_dir'),
                                            ('subject_id', 'subject_id')]),
-        (autorecon_surfs, autorecon3, [(('subjects_dir', _dedup), 'subjects_dir'),
+        (autorecon_surfs, cortribbon, [(('subjects_dir', _dedup), 'subjects_dir'),
                                        (('subject_id', _dedup), 'subject_id')]),
-        (autorecon3, outputnode, [(('subjects_dir', _dedup), 'subjects_dir'),
-                                  (('subject_id', _dedup), 'subject_id')]),
-        (autorecon3, recon_report, [(('subjects_dir', _dedup), 'subjects_dir'),
-                                    (('subject_id', _dedup), 'subject_id')]),
-        (recon_report, outputnode, [('out_report', 'out_report')]),
+        (cortribbon, parcstats, [('subjects_dir', 'subjects_dir'),
+                                 ('subject_id', 'subject_id')]),
+        (parcstats, autorecon3, [(('subjects_dir', _dedup), 'subjects_dir'),
+                                 (('subject_id', _dedup), 'subject_id')]),
+        (autorecon3, outputnode, [('subjects_dir', 'subjects_dir'),
+                                  ('subject_id', 'subject_id')]),
     ])
 
     return workflow
@@ -391,7 +398,7 @@ def init_autorecon_resume_wf(omp_nthreads, name='autorecon_resume_wf'):
 
 def init_gifti_surface_wf(name='gifti_surface_wf'):
     r"""
-    This workflow prepares GIFTI surfaces from a FreeSurfer subjects directory
+    Prepare GIFTI surfaces from a FreeSurfer subjects directory.
 
     If midthickness (or graymid) surfaces do not exist, they are generated and
     saved to the subject directory as ``lh/rh.midthickness``.
@@ -401,33 +408,34 @@ def init_gifti_surface_wf(name='gifti_surface_wf'):
     Additionally, the vertex coordinates are :py:class:`recentered
     <smriprep.interfaces.NormalizeSurf>` to align with native T1w space.
 
-    .. workflow::
-        :graph2use: orig
-        :simple_form: yes
+    Workflow Graph
+        .. workflow::
+            :graph2use: orig
+            :simple_form: yes
 
-        from smriprep.workflows.surfaces import init_gifti_surface_wf
-        wf = init_gifti_surface_wf()
+            from smriprep.workflows.surfaces import init_gifti_surface_wf
+            wf = init_gifti_surface_wf()
 
-    **Inputs**
+    Inputs
+    ------
+    subjects_dir
+        FreeSurfer SUBJECTS_DIR
+    subject_id
+        FreeSurfer subject ID
+    fsnative2t1w_xfm
+        LTA formatted affine transform file (inverse)
 
-        subjects_dir
-            FreeSurfer SUBJECTS_DIR
-        subject_id
-            FreeSurfer subject ID
-        t1_2_fsnative_reverse_transform
-            LTA formatted affine transform file (inverse)
-
-    **Outputs**
-
-        surfaces
-            GIFTI surfaces for gray/white matter boundary, pial surface,
-            midthickness (or graymid) surface, and inflated surfaces
+    Outputs
+    -------
+    surfaces
+        GIFTI surfaces for gray/white matter boundary, pial surface,
+        midthickness (or graymid) surface, and inflated surfaces
 
     """
     workflow = Workflow(name=name)
 
     inputnode = pe.Node(niu.IdentityInterface(['subjects_dir', 'subject_id',
-                                               't1_2_fsnative_reverse_transform']),
+                                               'fsnative2t1w_xfm']),
                         name='inputnode')
     outputnode = pe.Node(niu.IdentityInterface(['surfaces']), name='outputnode')
 
@@ -443,8 +451,8 @@ def init_gifti_surface_wf(name='gifti_surface_wf'):
 
     surface_list = pe.Node(niu.Merge(4, ravel_inputs=True),
                            name='surface_list', run_without_submitting=True)
-    fs_2_gii = pe.MapNode(fs.MRIsConvert(out_datatype='gii'),
-                          iterfield='in_file', name='fs_2_gii')
+    fs2gii = pe.MapNode(fs.MRIsConvert(out_datatype='gii'),
+                        iterfield='in_file', name='fs2gii')
     fix_surfs = pe.MapNode(NormalizeSurf(), iterfield='in_file', name='fix_surfs')
 
     workflow.connect([
@@ -461,9 +469,9 @@ def init_gifti_surface_wf(name='gifti_surface_wf'):
                                       ('pial', 'in2'),
                                       ('inflated', 'in3')]),
         (save_midthickness, surface_list, [('out_file', 'in4')]),
-        (surface_list, fs_2_gii, [('out', 'in_file')]),
-        (fs_2_gii, fix_surfs, [('converted', 'in_file')]),
-        (inputnode, fix_surfs, [('t1_2_fsnative_reverse_transform', 'transform_file')]),
+        (surface_list, fs2gii, [('out', 'in_file')]),
+        (fs2gii, fix_surfs, [('converted', 'in_file')]),
+        (inputnode, fix_surfs, [('fsnative2t1w_xfm', 'transform_file')]),
         (fix_surfs, outputnode, [('out_file', 'surfaces')]),
     ])
     return workflow
@@ -471,35 +479,35 @@ def init_gifti_surface_wf(name='gifti_surface_wf'):
 
 def init_segs_to_native_wf(name='segs_to_native', segmentation='aseg'):
     """
-    Get a segmentation from FreeSurfer conformed space into native T1w space
+    Get a segmentation from FreeSurfer conformed space into native T1w space.
 
+    Workflow Graph
+        .. workflow::
+            :graph2use: orig
+            :simple_form: yes
 
-    .. workflow::
-        :graph2use: orig
-        :simple_form: yes
+            from smriprep.workflows.surfaces import init_segs_to_native_wf
+            wf = init_segs_to_native_wf()
 
-        from smriprep.workflows.surfaces import init_segs_to_native_wf
-        wf = init_segs_to_native_wf()
+    Parameters
+    ----------
+    segmentation
+        The name of a segmentation ('aseg' or 'aparc_aseg' or 'wmparc')
 
+    Inputs
+    ------
+    in_file
+        Anatomical, merged T1w image after INU correction
+    subjects_dir
+        FreeSurfer SUBJECTS_DIR
+    subject_id
+        FreeSurfer subject ID
 
-    **Parameters**
-        segmentation
-            The name of a segmentation ('aseg' or 'aparc_aseg' or 'wmparc')
+    Outputs
+    -------
+    out_file
+        The selected segmentation, after resampling in native space
 
-    **Inputs**
-
-        in_file
-            Anatomical, merged T1w image after INU correction
-        subjects_dir
-            FreeSurfer SUBJECTS_DIR
-        subject_id
-            FreeSurfer subject ID
-
-
-    **Outputs**
-
-        out_file
-            The selected segmentation, after resampling in native space
     """
     workflow = Workflow(name='%s_%s' % (name, segmentation))
     inputnode = pe.Node(niu.IdentityInterface([
@@ -512,11 +520,11 @@ def init_segs_to_native_wf(name='segs_to_native', segmentation='aseg'):
 
     if segmentation.startswith('aparc'):
         if segmentation == 'aparc_aseg':
-            def _sel(x): return [parc for parc in x if 'aparc+' in parc][0]
+            def _sel(x): return [parc for parc in x if 'aparc+' in parc][0]  # noqa
         elif segmentation == 'aparc_a2009s':
-            def _sel(x): return [parc for parc in x if 'a2009s+' in parc][0]
+            def _sel(x): return [parc for parc in x if 'a2009s+' in parc][0]  # noqa
         elif segmentation == 'aparc_dkt':
-            def _sel(x): return [parc for parc in x if 'DKTatlas+' in parc][0]
+            def _sel(x): return [parc for parc in x if 'DKTatlas+' in parc][0]  # noqa
         segmentation = (segmentation, _sel)
 
     workflow.connect([
@@ -534,9 +542,12 @@ def init_segs_to_native_wf(name='segs_to_native', segmentation='aseg'):
 
 
 def _check_cw256(in_files):
+    import numpy as np
     from nibabel.funcs import concat_images
     if isinstance(in_files, str):
         in_files = [in_files]
-    if any((s > 256 for s in concat_images(in_files).shape[:3])):
+    summary_img = concat_images(in_files)
+    fov = np.array(summary_img.shape[:3]) * summary_img.header.get_zooms()[:3]
+    if np.any(fov > 256):
         return ['-noskullstrip', '-cw256']
     return '-noskullstrip'
